# Frequently asked questions

1. [What should I do when my 'posterior samples are outside of the prior support' in SNPE?](faq/question_01_leakage.md)
2. [Can the algorithms deal with invalid data, e.g., NaN or inf?](faq/question_02_nans.md)
3. [When using multiple workers, I get a pickling error. Can I still use multiprocessing?](faq/question_03_pickling_error.md)
4. [Can I use the GPU for training the density estimator?](faq/question_04_gpu.md)
5. [How should I save and load objects in `sbi`?](faq/question_05_pickling.md)
6. [Can I stop neural network training and resume it later?](faq/question_06_resume_training.md)
7. [How can I use a prior that is not defined in PyTorch?](faq/question_07_custom_prior.md)

See also [discussion page](https://github.com/sbi-dev/sbi/discussions) and [issue
tracker](https://github.com/sbi-dev/sbi/issues) on the `sbi` GitHub repository for
recent questions and problems.
